
From: Andi Kleen <ak@suse.de>

I've been working since some time on an implementation of the NUMA API
discussed at last kernel summit.  So far the development was on x86-64, but
other people are starting to test on other architectures too.  To avoid
problems with unassigned system calls I would like to reserve official
system call numbers for the numa system calls.

The NUMA policy kernel interface consists of three new system calls: mbind
(change policy for a VMA), set_mempolicy (set policy for a process),
get_mempolicy (get policy).  I won't bore you with details, man pages can
be found at

http://www.firstfloor.org/~andi/mbind.html
http://www.firstfloor.org/~andi/set_mempolicy.html
http://www.firstfloor.org/~andi/get_mempolicy.html

This patch reserves i386 system call slots for these three syscalls. 



---

 arch/i386/kernel/entry.S  |    3 +++
 include/asm-i386/unistd.h |    5 ++++-
 2 files changed, 7 insertions(+), 1 deletion(-)

diff -puN arch/i386/kernel/entry.S~reserve-NUMA-API-syscall-slots arch/i386/kernel/entry.S
--- 25/arch/i386/kernel/entry.S~reserve-NUMA-API-syscall-slots	2004-01-24 14:56:12.000000000 -0800
+++ 25-akpm/arch/i386/kernel/entry.S	2004-01-24 14:56:12.000000000 -0800
@@ -908,5 +908,8 @@ ENTRY(sys_call_table)
 	.long sys_utimes
  	.long sys_fadvise64_64
 	.long sys_ni_syscall	/* sys_vserver */
+	.long sys_ni_syscall	/* mbind */
+	.long sys_ni_syscall	/* get_mempolicy */
+	.long sys_ni_syscall	/* set_mempolicy */
 
 syscall_table_size=(.-sys_call_table)
diff -puN include/asm-i386/unistd.h~reserve-NUMA-API-syscall-slots include/asm-i386/unistd.h
--- 25/include/asm-i386/unistd.h~reserve-NUMA-API-syscall-slots	2004-01-24 14:56:12.000000000 -0800
+++ 25-akpm/include/asm-i386/unistd.h	2004-01-24 14:56:12.000000000 -0800
@@ -279,8 +279,11 @@
 #define __NR_utimes		271
 #define __NR_fadvise64_64	272
 #define __NR_vserver		273
+#define __NR_mbind		274
+#define __NR_get_mempolicy	275
+#define __NR_set_mempolicy	276
 
-#define NR_syscalls 274
+#define NR_syscalls 276
 
 /* user-visible error numbers are in the range -1 - -124: see <asm-i386/errno.h> */
 

_
